@@ -24,7 +24,7 @@ class DatabaseType(str, Enum):
 
 
 class Settings(BaseSettings):
-    VERSION: str = "0.4.2"
+    VERSION: str = "0.4.3"
     API_VERSION: int = 1
     API_PRE_PATH: str = f"/api/v{API_VERSION}"
 
@@ -33,7 +33,7 @@ class Settings(BaseSettings):
     UNIT_TESTING: bool = False
 
     SECRET_KEY: SecretBytes = os.urandom(32)
-    BUILD_DATE: Optional[datetime] = None
+    BUILD_DATE: Optional[str] = None
     PROJECT_NAME: str = "FastAPI Backend"
     BACKEND_CORS_ORIGINS: Set[str] = set()
     MINIO_SECRET_KEY: Optional[SecretStr] = None
